summaryrefslogtreecommitdiffstats
path: root/src/com/android/browser/TitleBar.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/com/android/browser/TitleBar.java')
-rw-r--r--src/com/android/browser/TitleBar.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/com/android/browser/TitleBar.java b/src/com/android/browser/TitleBar.java
index 6dabd76f2..bdef82e95 100644
--- a/src/com/android/browser/TitleBar.java
+++ b/src/com/android/browser/TitleBar.java
@@ -320,13 +320,13 @@ public class TitleBar extends TitleBarBase {
/**
* Update the text displayed in the title bar.
* @param title String to display. If null, the loading string will be
* shown.
*/
@Override
void setDisplayTitle(String title) {
if (title == null) {
- mTitle.setText(R.string.title_bar_loading);
+ mTitle.setText(R.string.new_tab);
} else {
if (mInVoiceMode) {
// Add two spaces. The second one will be replaced with an
@@ -320,13 +320,13 @@ public class TitleBar extends TitleBarBase {
/**
* Update the text displayed in the title bar.
- * @param title String to display. If null, the loading string will be
+ * @param title String to display. If null, the new tab string will be
* shown.
*/